﻿/*
using System;
using System.IO;
using System.Runtime.Serialization;
using com.calitha.goldparser.lalr;
using com.calitha.commons;
using System.Windows.Forms;
using RTMALG;

namespace com.calitha.goldparser
{

    [Serializable()]
    public class SymbolException : System.Exception
    {
        public SymbolException(string message) : base(message)
        {
        }

        public SymbolException(string message,
            Exception inner) : base(message, inner)
        {
        }

        protected SymbolException(SerializationInfo info,
            StreamingContext context) : base(info, context)
        {
        }

    }

    [Serializable()]
    public class RuleException : System.Exception
    {

        public RuleException(string message) : base(message)
        {
        }

        public RuleException(string message,
                             Exception inner) : base(message, inner)
        {
        }

        protected RuleException(SerializationInfo info,
                                StreamingContext context) : base(info, context)
        {
        }

    }

    enum SymbolConstants : int
    {
        SYMBOL_EOF                  =  0, // (EOF)
        SYMBOL_ERROR                =  1, // (Error)
        SYMBOL_COMMENT              =  2, // Comment
        SYMBOL_WHITESPACE           =  3, // Whitespace
        SYMBOL_LBRACELBRACE         =  4, // '{{'
        SYMBOL_RBRACERBRACE         =  5, // '}}'
        SYMBOL_MINUS                =  6, // '-'
        SYMBOL_LPAREN               =  7, // '('
        SYMBOL_RPAREN               =  8, // ')'
        SYMBOL_TIMES                =  9, // '*'
        SYMBOL_COMMA                = 10, // ','
        SYMBOL_DIV                  = 11, // '/'
        SYMBOL_COLONEQ              = 12, // ':='
        SYMBOL_LBRACKET             = 13, // '['
        SYMBOL_RBRACKET             = 14, // ']'
        SYMBOL_PLUS                 = 15, // '+'
        SYMBOL_LT                   = 16, // '<'
        SYMBOL_LTEQ                 = 17, // '<='
        SYMBOL_LTGT                 = 18, // '<>'
        SYMBOL_EQ                   = 19, // '='
        SYMBOL_EQGT                 = 20, // '=>'
        SYMBOL_GT                   = 21, // '>'
        SYMBOL_CADENA               = 22, // cadena
        SYMBOL_CARACTER             = 23, // caracter
        SYMBOL_CONTRARIO            = 24, // contrario
        SYMBOL_DCADENA              = 25, // DCADENA
        SYMBOL_DCARACTER            = 26, // DCARACTER
        SYMBOL_DDECIMAL             = 27, // DDECIMAL
        SYMBOL_DE                   = 28, // De
        SYMBOL_DECIMAL              = 29, // decimal
        SYMBOL_DENTERO              = 30, // DENTERO
        SYMBOL_DESDE                = 31, // Desde
        SYMBOL_ENTERO               = 32, // entero
        SYMBOL_ENTONCES             = 33, // Entonces
        SYMBOL_FIN                  = 34, // Fin
        SYMBOL_FINREPETIR           = 35, // FinRepetir
        SYMBOL_FINSI                = 36, // FinSi
        SYMBOL_HACER                = 37, // Hacer
        SYMBOL_HASTA                = 38, // Hasta
        SYMBOL_ID                   = 39, // ID
        SYMBOL_INICIO               = 40, // Inicio
        SYMBOL_LO                   = 41, // lo
        SYMBOL_MIENTRAS             = 42, // Mientras
        SYMBOL_O                    = 43, // o
        SYMBOL_PARA                 = 44, // Para
        SYMBOL_REPETIR              = 45, // Repetir
        SYMBOL_RUTINA               = 46, // Rutina
        SYMBOL_SI                   = 47, // Si
        SYMBOL_SUBRUTINA            = 48, // Subrutina
        SYMBOL_VARIABLES            = 49, // Variables
        SYMBOL_Y                    = 50, // y
        SYMBOL_ADDEXP               = 51, // <Add Exp>
        SYMBOL_COMPAREEXP           = 52, // <Compare Exp>
        SYMBOL_CONDICION            = 53, // <Condicion>
        SYMBOL_CUERPOFIN            = 54, // <CuerpoFin>
        SYMBOL_CUERPOINICIO         = 55, // <CuerpoInicio>
        SYMBOL_CUERPORUTINA         = 56, // <CuerpoRutina>
        SYMBOL_CUERPOSUBRUTINA      = 57, // <CuerpoSubrutina>
        SYMBOL_CUERPOVARIABLE       = 58, // <CuerpoVariable>
        SYMBOL_DECFUNCIONPARAMETROS = 59, // <Dec Funcion Parametros>
        SYMBOL_DECLIST              = 60, // <Dec List>
        SYMBOL_DECLLAMARFUNCION     = 61, // <Dec Llamar Funcion>
        SYMBOL_DECREPETIRHACER      = 62, // <Dec Repetir Hacer>
        SYMBOL_DECREPETIRMIENTRAS   = 63, // <Dec Repetir Mientras>
        SYMBOL_DECRPETIRPARA        = 64, // <Dec Rpetir Para>
        SYMBOL_DECSI                = 65, // <Dec Si>
        SYMBOL_DECSICONTRARIO       = 66, // <Dec Si Contrario>
        SYMBOL_DECVAR               = 67, // <Dec Var>
        SYMBOL_DECVARCUERPO         = 68, // <Dec Var Cuerpo>
        SYMBOL_DECLARACION          = 69, // <Declaracion>
        SYMBOL_DECSUBRUTINA         = 70, // <DecSubrutina>
        SYMBOL_EXPLIST              = 71, // <Exp List>
        SYMBOL_EXPRESION            = 72, // <Expresion>
        SYMBOL_HASTADATO            = 73, // <Hasta Dato>
        SYMBOL_INICIAL              = 74, // <Inicial>
        SYMBOL_INICIALIZARVAR       = 75, // <Inicializar Var>
        SYMBOL_INICIO2              = 76, // <Inicio>
        SYMBOL_LOCALVARDEC          = 77, // <Local Var Dec>
        SYMBOL_LOGICAEXP            = 78, // <Logica Exp>
        SYMBOL_MULTEXP              = 79, // <Mult Exp>
        SYMBOL_OPADD                = 80, // <Op Add>
        SYMBOL_OPLOGICO             = 81, // <Op Logico>
        SYMBOL_OPMULT               = 82, // <Op Mult>
        SYMBOL_OPRELACIONAL         = 83, // <Op Relacional>
        SYMBOL_PARAMETROLLAMADA     = 84, // <ParametroLlamada>
        SYMBOL_PARAMETRORECIBE      = 85, // <ParametroRecibe>
        SYMBOL_PRIMARIO             = 86, // <Primario>
        SYMBOL_RUTINA2              = 87, // <Rutina>
        SYMBOL_SUBRUTINA2           = 88, // <Subrutina>
        SYMBOL_TIPOBASE             = 89, // <Tipo Base>
        SYMBOL_TIPOVALOR            = 90, // <Tipo Valor>
        SYMBOL_UNARIO               = 91, // <Unario>
        SYMBOL_VARDECCUERPOINI      = 92, // <Var Dec Cuerpo Ini>
        SYMBOL_VARDECLARACION       = 93  // <Var Declaracion>
    };

    enum RuleConstants : int
    {
        RULE_CUERPOVARIABLE_VARIABLES                          =  0, // <CuerpoVariable> ::= Variables
        RULE_CUERPOINICIO_INICIO                               =  1, // <CuerpoInicio> ::= Inicio
        RULE_CUERPOFIN_FIN                                     =  2, // <CuerpoFin> ::= Fin
        RULE_CUERPOSUBRUTINA_SUBRUTINA                         =  3, // <CuerpoSubrutina> ::= Subrutina
        RULE_CUERPORUTINA_RUTINA_ID                            =  4, // <CuerpoRutina> ::= Rutina ID
        RULE_INICIO                                            =  5, // <Inicio> ::= <Rutina>
        RULE_INICIO2                                           =  6, // <Inicio> ::= <Subrutina> <Rutina>
        RULE_RUTINA                                            =  7, // <Rutina> ::= <CuerpoRutina> <CuerpoVariable> <CuerpoInicio> <CuerpoFin>
        RULE_RUTINA2                                           =  8, // <Rutina> ::= <CuerpoRutina> <CuerpoVariable> <Local Var Dec> <CuerpoInicio> <CuerpoFin>
        RULE_RUTINA3                                           =  9, // <Rutina> ::= <CuerpoRutina> <CuerpoVariable> <CuerpoInicio> <Dec List> <CuerpoFin>
        RULE_RUTINA4                                           = 10, // <Rutina> ::= <CuerpoRutina> <CuerpoVariable> <Local Var Dec> <CuerpoInicio> <Dec List> <CuerpoFin>
        RULE_SUBRUTINA                                         = 11, // <Subrutina> ::= <DecSubrutina> <CuerpoVariable> <CuerpoInicio> <CuerpoFin>
        RULE_SUBRUTINA2                                        = 12, // <Subrutina> ::= <DecSubrutina> <CuerpoVariable> <Local Var Dec> <CuerpoInicio> <CuerpoFin>
        RULE_SUBRUTINA3                                        = 13, // <Subrutina> ::= <DecSubrutina> <CuerpoVariable> <CuerpoInicio> <Dec List> <CuerpoFin>
        RULE_SUBRUTINA4                                        = 14, // <Subrutina> ::= <DecSubrutina> <CuerpoVariable> <Local Var Dec> <CuerpoInicio> <Dec List> <CuerpoFin>
        RULE_SUBRUTINA5                                        = 15, // <Subrutina> ::= <DecSubrutina> <CuerpoVariable> <CuerpoInicio> <CuerpoFin> <Subrutina>
        RULE_SUBRUTINA6                                        = 16, // <Subrutina> ::= <DecSubrutina> <CuerpoVariable> <Local Var Dec> <CuerpoInicio> <CuerpoFin> <Subrutina>
        RULE_SUBRUTINA7                                        = 17, // <Subrutina> ::= <DecSubrutina> <CuerpoVariable> <CuerpoInicio> <Dec List> <CuerpoFin> <Subrutina>
        RULE_SUBRUTINA8                                        = 18, // <Subrutina> ::= <DecSubrutina> <CuerpoVariable> <Local Var Dec> <CuerpoInicio> <Dec List> <CuerpoFin> <Subrutina>
        RULE_DECSUBRUTINA                                      = 19, // <DecSubrutina> ::= <CuerpoSubrutina> <Dec Funcion Parametros>
        RULE_DECLIST                                           = 20, // <Dec List> ::= <Dec List> <Declaracion>
        RULE_DECLIST2                                          = 21, // <Dec List> ::= <Declaracion>
        RULE_DECLARACION                                       = 22, // <Declaracion> ::= <Dec Var Cuerpo>
        RULE_DECLARACION2                                      = 23, // <Declaracion> ::= <Dec Si>
        RULE_DECLARACION3                                      = 24, // <Declaracion> ::= <Dec Repetir Mientras>
        RULE_DECLARACION4                                      = 25, // <Declaracion> ::= <Dec Repetir Hacer>
        RULE_DECLARACION5                                      = 26, // <Declaracion> ::= <Dec Rpetir Para>
        RULE_DECLARACION6                                      = 27, // <Declaracion> ::= <Dec Llamar Funcion>
        RULE_DECVARCUERPO_ID_COLONEQ                           = 28, // <Dec Var Cuerpo> ::= ID ':=' <Var Dec Cuerpo Ini>
        RULE_DECVARCUERPO_ID_COLONEQ2                          = 29, // <Dec Var Cuerpo> ::= ID ':=' <Dec Llamar Funcion>
        RULE_DECVARCUERPO_ID_LBRACKET_RBRACKET_COLONEQ         = 30, // <Dec Var Cuerpo> ::= ID '[' <Expresion> ']' ':=' <Var Dec Cuerpo Ini>
        RULE_VARDECCUERPOINI                                   = 31, // <Var Dec Cuerpo Ini> ::= <Expresion>
        RULE_LOCALVARDEC                                       = 32, // <Local Var Dec> ::= <Tipo Base> <Dec Var>
        RULE_LOCALVARDEC2                                      = 33, // <Local Var Dec> ::= <Local Var Dec> <Tipo Base> <Dec Var>
        RULE_DECVAR                                            = 34, // <Dec Var> ::= <Var Declaracion>
        RULE_VARDECLARACION                                    = 35, // <Var Declaracion> ::= <Inicial>
        RULE_VARDECLARACION_COMMA                              = 36, // <Var Declaracion> ::= <Var Declaracion> ',' <Inicial>
        RULE_VARDECLARACION_ID_COLONEQ                         = 37, // <Var Declaracion> ::= ID ':=' <Inicializar Var>
        RULE_VARDECLARACION_COMMA_ID_COLONEQ                   = 38, // <Var Declaracion> ::= <Var Declaracion> ',' ID ':=' <Inicializar Var>
        RULE_INICIAL_ID                                        = 39, // <Inicial> ::= ID
        RULE_INICIAL_ID_LBRACKET_RBRACKET                      = 40, // <Inicial> ::= ID '[' <Expresion> ']'
        RULE_INICIALIZARVAR                                    = 41, // <Inicializar Var> ::= <Expresion>
        RULE_TIPOBASE_ENTERO                                   = 42, // <Tipo Base> ::= entero
        RULE_TIPOBASE_DECIMAL                                  = 43, // <Tipo Base> ::= decimal
        RULE_TIPOBASE_CADENA                                   = 44, // <Tipo Base> ::= cadena
        RULE_TIPOBASE_CARACTER                                 = 45, // <Tipo Base> ::= caracter
        RULE_TIPOVALOR_DENTERO                                 = 46, // <Tipo Valor> ::= DENTERO
        RULE_TIPOVALOR_DDECIMAL                                = 47, // <Tipo Valor> ::= DDECIMAL
        RULE_TIPOVALOR_DCADENA                                 = 48, // <Tipo Valor> ::= DCADENA
        RULE_TIPOVALOR_DCARACTER                               = 49, // <Tipo Valor> ::= DCARACTER
        RULE_OPADD_PLUS                                        = 50, // <Op Add> ::= '+'
        RULE_OPADD_MINUS                                       = 51, // <Op Add> ::= '-'
        RULE_OPMULT_TIMES                                      = 52, // <Op Mult> ::= '*'
        RULE_OPMULT_DIV                                        = 53, // <Op Mult> ::= '/'
        RULE_OPRELACIONAL_LT                                   = 54, // <Op Relacional> ::= '<'
        RULE_OPRELACIONAL_GT                                   = 55, // <Op Relacional> ::= '>'
        RULE_OPRELACIONAL_EQGT                                 = 56, // <Op Relacional> ::= '=>'
        RULE_OPRELACIONAL_LTEQ                                 = 57, // <Op Relacional> ::= '<='
        RULE_OPRELACIONAL_EQ                                   = 58, // <Op Relacional> ::= '='
        RULE_OPRELACIONAL_LTGT                                 = 59, // <Op Relacional> ::= '<>'
        RULE_OPLOGICO_Y                                        = 60, // <Op Logico> ::= y
        RULE_OPLOGICO_O                                        = 61, // <Op Logico> ::= o
        RULE_EXPRESION                                         = 62, // <Expresion> ::= <Exp List>
        RULE_EXPLIST                                           = 63, // <Exp List> ::= <Logica Exp>
        RULE_LOGICAEXP                                         = 64, // <Logica Exp> ::= <Logica Exp> <Op Logico> <Compare Exp>
        RULE_LOGICAEXP2                                        = 65, // <Logica Exp> ::= <Compare Exp>
        RULE_COMPAREEXP                                        = 66, // <Compare Exp> ::= <Compare Exp> <Op Relacional> <Add Exp>
        RULE_COMPAREEXP2                                       = 67, // <Compare Exp> ::= <Add Exp>
        RULE_ADDEXP                                            = 68, // <Add Exp> ::= <Add Exp> <Op Add> <Mult Exp>
        RULE_ADDEXP2                                           = 69, // <Add Exp> ::= <Mult Exp>
        RULE_MULTEXP                                           = 70, // <Mult Exp> ::= <Mult Exp> <Op Mult> <Unario>
        RULE_MULTEXP2                                          = 71, // <Mult Exp> ::= <Unario>
        RULE_UNARIO_MINUS                                      = 72, // <Unario> ::= '-' <Unario>
        RULE_UNARIO                                            = 73, // <Unario> ::= <Primario>
        RULE_PRIMARIO                                          = 74, // <Primario> ::= <Tipo Valor>
        RULE_PRIMARIO_ID                                       = 75, // <Primario> ::= ID
        RULE_PRIMARIO_LPAREN_RPAREN                            = 76, // <Primario> ::= '(' <Expresion> ')'
        RULE_DECSI_SI_ENTONCES_FINSI                           = 77, // <Dec Si> ::= Si <Condicion> Entonces <Dec List> FinSi
        RULE_DECSI_SI_ENTONCES_FINSI2                          = 78, // <Dec Si> ::= Si <Condicion> Entonces <Dec List> <Dec Si Contrario> FinSi
        RULE_CONDICION_LPAREN_RPAREN                           = 79, // <Condicion> ::= '(' <Expresion> ')'
        RULE_CONDICION_LPAREN_RPAREN2                          = 80, // <Condicion> ::= <Condicion> <Op Relacional> '(' <Expresion> ')'
        RULE_CONDICION_LPAREN_RPAREN3                          = 81, // <Condicion> ::= <Condicion> <Op Logico> '(' <Expresion> ')'
        RULE_DECSICONTRARIO_DE_LO_CONTRARIO                    = 82, // <Dec Si Contrario> ::= De lo contrario <Dec List>
        RULE_DECREPETIRMIENTRAS_REPETIR_MIENTRAS_FINREPETIR    = 83, // <Dec Repetir Mientras> ::= Repetir Mientras <Expresion> <Dec List> FinRepetir
        RULE_DECREPETIRHACER_REPETIR_HACER_MIENTRAS_FINREPETIR = 84, // <Dec Repetir Hacer> ::= Repetir Hacer <Dec List> Mientras <Expresion> FinRepetir
        RULE_DECRPETIRPARA_REPETIR_PARA_DESDE_HASTA_FINREPETIR = 85, // <Dec Rpetir Para> ::= Repetir Para <Hasta Dato> Desde <Hasta Dato> Hasta <Hasta Dato> <Dec List> FinRepetir
        RULE_HASTADATO_ID                                      = 86, // <Hasta Dato> ::= ID
        RULE_HASTADATO_DENTERO                                 = 87, // <Hasta Dato> ::= DENTERO
        RULE_DECLLAMARFUNCION_ID_LPAREN_RPAREN                 = 88, // <Dec Llamar Funcion> ::= ID '(' ')'
        RULE_DECLLAMARFUNCION_ID_LPAREN_RPAREN2                = 89, // <Dec Llamar Funcion> ::= ID '(' <ParametroLlamada> ')'
        RULE_PARAMETROLLAMADA_ID                               = 90, // <ParametroLlamada> ::= ID
        RULE_PARAMETROLLAMADA                                  = 91, // <ParametroLlamada> ::= <Tipo Valor>
        RULE_PARAMETROLLAMADA_COMMA                            = 92, // <ParametroLlamada> ::= <ParametroLlamada> ',' <Tipo Valor>
        RULE_PARAMETROLLAMADA_COMMA_ID                         = 93, // <ParametroLlamada> ::= <ParametroLlamada> ',' ID
        RULE_DECFUNCIONPARAMETROS_ID_LPAREN_RPAREN             = 94, // <Dec Funcion Parametros> ::= ID '(' ')'
        RULE_DECFUNCIONPARAMETROS_ID_LPAREN_RPAREN2            = 95, // <Dec Funcion Parametros> ::= ID '(' <ParametroRecibe> ')'
        RULE_PARAMETRORECIBE_ID                                = 96, // <ParametroRecibe> ::= <Tipo Base> ID
        RULE_PARAMETRORECIBE_COMMA_ID                          = 97  // <ParametroRecibe> ::= <ParametroRecibe> ',' <Tipo Base> ID
    };

    public class MyParser
    {
        private LALRParser parser;

        public MyParser(string filename)
        {
            FileStream stream = new FileStream(filename,
                                               FileMode.Open, 
                                               FileAccess.Read, 
                                               FileShare.Read);
            Init(stream);
            stream.Close();
        }

        public MyParser(string baseName, string resourceName)
        {
            byte[] buffer = ResourceUtil.GetByteArrayResource(
                System.Reflection.Assembly.GetExecutingAssembly(),
                baseName,
                resourceName);
            MemoryStream stream = new MemoryStream(buffer);
            Init(stream);
            stream.Close();
        }

        public MyParser(Stream stream)
        {
            Init(stream);
        }

        private void Init(Stream stream)
        {
            CGTReader reader = new CGTReader(stream);
            parser = reader.CreateNewParser();
            parser.TrimReductions = false;
            parser.StoreTokens = LALRParser.StoreTokensMode.NoUserObject;

            parser.OnReduce += new LALRParser.ReduceHandler(ReduceEvent);
            parser.OnTokenRead += new LALRParser.TokenReadHandler(TokenReadEvent);
            parser.OnAccept += new LALRParser.AcceptHandler(AcceptEvent);
            parser.OnTokenError += new LALRParser.TokenErrorHandler(TokenErrorEvent);
            parser.OnParseError += new LALRParser.ParseErrorHandler(ParseErrorEvent);
        }

        public void Parse(string source)
        {
            parser.Parse(source);

        }

        private void TokenReadEvent(LALRParser parser, TokenReadEventArgs args)
        {
            try
            {
                args.Token.UserObject = CreateObject(args.Token);
            }
            catch (Exception e)
            {
                args.Continue = false;
                //todo: Report message to UI?
            }
        }

        private Object CreateObject(TerminalToken token)
        {
            switch (token.Symbol.Id)
            {
                case (int)SymbolConstants.SYMBOL_EOF :
                //(EOF)
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_ERROR :
                //(Error)
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_COMMENT :
                //Comment
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_WHITESPACE :
                //Whitespace
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_LBRACELBRACE :
                //'{{'
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_RBRACERBRACE :
                //'}}'
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_MINUS :
                //'-'
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_LPAREN :
                //'('
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_RPAREN :
                //')'
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_TIMES :
                //'*'
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_COMMA :
                //','
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_DIV :
                //'/'
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_COLONEQ :
                //':='
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_LBRACKET :
                //'['
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_RBRACKET :
                //']'
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_PLUS :
                //'+'
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_LT :
                //'<'
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_LTEQ :
                //'<='
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_LTGT :
                //'<>'
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_EQ :
                //'='
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_EQGT :
                //'=>'
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_GT :
                //'>'
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_CADENA :
                //cadena
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_CARACTER :
                //caracter
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_CONTRARIO :
                //contrario
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_DCADENA :
                //DCADENA
                //todo: Create a new object that corresponds to the symbol
                return token.Text;

                case (int)SymbolConstants.SYMBOL_DCARACTER :
                //DCARACTER
                //todo: Create a new object that corresponds to the symbol
                return token.Text;

                case (int)SymbolConstants.SYMBOL_DDECIMAL :
                //DDECIMAL
                //todo: Create a new object that corresponds to the symbol
                return token.Text;

                case (int)SymbolConstants.SYMBOL_DE :
                //De
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_DECIMAL :
                //decimal
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_DENTERO :
                //DENTERO
                //todo: Create a new object that corresponds to the symbol
                return token.Text;

                case (int)SymbolConstants.SYMBOL_DESDE :
                //Desde
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_ENTERO :
                //entero
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_ENTONCES :
                //Entonces
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_FIN :
                //Fin
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_FINREPETIR :
                //FinRepetir
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_FINSI :
                //FinSi
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_HACER :
                //Hacer
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_HASTA :
                //Hasta
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_ID :
                //ID
                //todo: Create a new object that corresponds to the symbol
                return token.Text;

                case (int)SymbolConstants.SYMBOL_INICIO :
                //Inicio
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_LO :
                //lo
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_MIENTRAS :
                //Mientras
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_O :
                //o
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_PARA :
                //Para
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_REPETIR :
                //Repetir
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_RUTINA :
                //Rutina
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_SI :
                //Si
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_SUBRUTINA :
                //Subrutina
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_VARIABLES :
                //Variables
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_Y :
                //y
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_ADDEXP :
                //<Add Exp>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_COMPAREEXP :
                //<Compare Exp>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_CONDICION :
                //<Condicion>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_CUERPOFIN :
                //<CuerpoFin>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_CUERPOINICIO :
                //<CuerpoInicio>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_CUERPORUTINA :
                //<CuerpoRutina>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_CUERPOSUBRUTINA :
                //<CuerpoSubrutina>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_CUERPOVARIABLE :
                //<CuerpoVariable>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_DECFUNCIONPARAMETROS :
                //<Dec Funcion Parametros>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_DECLIST :
                //<Dec List>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_DECLLAMARFUNCION :
                //<Dec Llamar Funcion>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_DECREPETIRHACER :
                //<Dec Repetir Hacer>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_DECREPETIRMIENTRAS :
                //<Dec Repetir Mientras>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_DECRPETIRPARA :
                //<Dec Rpetir Para>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_DECSI :
                //<Dec Si>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_DECSICONTRARIO :
                //<Dec Si Contrario>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_DECVAR :
                //<Dec Var>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_DECVARCUERPO :
                //<Dec Var Cuerpo>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_DECLARACION :
                //<Declaracion>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_DECSUBRUTINA :
                //<DecSubrutina>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_EXPLIST :
                //<Exp List>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_EXPRESION :
                //<Expresion>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_HASTADATO :
                //<Hasta Dato>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_INICIAL :
                //<Inicial>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_INICIALIZARVAR :
                //<Inicializar Var>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_INICIO2 :
                //<Inicio>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_LOCALVARDEC :
                //<Local Var Dec>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_LOGICAEXP :
                //<Logica Exp>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_MULTEXP :
                //<Mult Exp>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_OPADD :
                //<Op Add>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_OPLOGICO :
                //<Op Logico>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_OPMULT :
                //<Op Mult>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_OPRELACIONAL :
                //<Op Relacional>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_PARAMETROLLAMADA :
                //<ParametroLlamada>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_PARAMETRORECIBE :
                //<ParametroRecibe>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_PRIMARIO :
                //<Primario>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_RUTINA2 :
                //<Rutina>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_SUBRUTINA2 :
                //<Subrutina>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_TIPOBASE :
                //<Tipo Base>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_TIPOVALOR :
                //<Tipo Valor>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_UNARIO :
                //<Unario>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_VARDECCUERPOINI :
                //<Var Dec Cuerpo Ini>
                //todo: Create a new object that corresponds to the symbol
                return null;

                case (int)SymbolConstants.SYMBOL_VARDECLARACION :
                //<Var Declaracion>
                //todo: Create a new object that corresponds to the symbol
                return null;

            }
            throw new SymbolException("Unknown symbol");
        }

        private void ReduceEvent(LALRParser parser, ReduceEventArgs args)
        {
            try
            {
                args.Token.UserObject = CreateObject(args.Token);
            }
            catch (Exception e)
            {
                args.Continue = false;
                //todo: Report message to UI?
            }
        }

        public static Object CreateObject(NonterminalToken token)
        {
            switch (token.Rule.Id)
            {
                case (int)RuleConstants.RULE_CUERPOVARIABLE_VARIABLES :
                //<CuerpoVariable> ::= Variables
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_CUERPOINICIO_INICIO :
                //<CuerpoInicio> ::= Inicio
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_CUERPOFIN_FIN :
                //<CuerpoFin> ::= Fin
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_CUERPOSUBRUTINA_SUBRUTINA :
                //<CuerpoSubrutina> ::= Subrutina
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_CUERPORUTINA_RUTINA_ID :
                //<CuerpoRutina> ::= Rutina ID
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_INICIO :
                //<Inicio> ::= <Rutina>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_INICIO2 :
                //<Inicio> ::= <Subrutina> <Rutina>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_RUTINA :
                //<Rutina> ::= <CuerpoRutina> <CuerpoVariable> <CuerpoInicio> <CuerpoFin>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_RUTINA2 :
                //<Rutina> ::= <CuerpoRutina> <CuerpoVariable> <Local Var Dec> <CuerpoInicio> <CuerpoFin>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_RUTINA3 :
                //<Rutina> ::= <CuerpoRutina> <CuerpoVariable> <CuerpoInicio> <Dec List> <CuerpoFin>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_RUTINA4 :
                //<Rutina> ::= <CuerpoRutina> <CuerpoVariable> <Local Var Dec> <CuerpoInicio> <Dec List> <CuerpoFin>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_SUBRUTINA :
                //<Subrutina> ::= <DecSubrutina> <CuerpoVariable> <CuerpoInicio> <CuerpoFin>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_SUBRUTINA2 :
                //<Subrutina> ::= <DecSubrutina> <CuerpoVariable> <Local Var Dec> <CuerpoInicio> <CuerpoFin>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_SUBRUTINA3 :
                //<Subrutina> ::= <DecSubrutina> <CuerpoVariable> <CuerpoInicio> <Dec List> <CuerpoFin>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_SUBRUTINA4 :
                //<Subrutina> ::= <DecSubrutina> <CuerpoVariable> <Local Var Dec> <CuerpoInicio> <Dec List> <CuerpoFin>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_SUBRUTINA5 :
                //<Subrutina> ::= <DecSubrutina> <CuerpoVariable> <CuerpoInicio> <CuerpoFin> <Subrutina>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_SUBRUTINA6 :
                //<Subrutina> ::= <DecSubrutina> <CuerpoVariable> <Local Var Dec> <CuerpoInicio> <CuerpoFin> <Subrutina>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_SUBRUTINA7 :
                //<Subrutina> ::= <DecSubrutina> <CuerpoVariable> <CuerpoInicio> <Dec List> <CuerpoFin> <Subrutina>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_SUBRUTINA8 :
                //<Subrutina> ::= <DecSubrutina> <CuerpoVariable> <Local Var Dec> <CuerpoInicio> <Dec List> <CuerpoFin> <Subrutina>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECSUBRUTINA :
                //<DecSubrutina> ::= <CuerpoSubrutina> <Dec Funcion Parametros>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECLIST :
                //<Dec List> ::= <Dec List> <Declaracion>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECLIST2 :
                //<Dec List> ::= <Declaracion>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECLARACION :
                //<Declaracion> ::= <Dec Var Cuerpo>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECLARACION2 :
                //<Declaracion> ::= <Dec Si>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECLARACION3 :
                //<Declaracion> ::= <Dec Repetir Mientras>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECLARACION4 :
                //<Declaracion> ::= <Dec Repetir Hacer>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECLARACION5 :
                //<Declaracion> ::= <Dec Rpetir Para>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECLARACION6 :
                //<Declaracion> ::= <Dec Llamar Funcion>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECVARCUERPO_ID_COLONEQ :
                //<Dec Var Cuerpo> ::= ID ':=' <Var Dec Cuerpo Ini>
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_DECVARCUERPO_ID_COLONEQ2 :
                //<Dec Var Cuerpo> ::= ID ':=' <Dec Llamar Funcion>
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_DECVARCUERPO_ID_LBRACKET_RBRACKET_COLONEQ :
                //<Dec Var Cuerpo> ::= ID '[' <Expresion> ']' ':=' <Var Dec Cuerpo Ini>
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_VARDECCUERPOINI :
                //<Var Dec Cuerpo Ini> ::= <Expresion>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_LOCALVARDEC :
                //<Local Var Dec> ::= <Tipo Base> <Dec Var>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_LOCALVARDEC2 :
                //<Local Var Dec> ::= <Local Var Dec> <Tipo Base> <Dec Var>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECVAR :
                //<Dec Var> ::= <Var Declaracion>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_VARDECLARACION :
                //<Var Declaracion> ::= <Inicial>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_VARDECLARACION_COMMA :
                //<Var Declaracion> ::= <Var Declaracion> ',' <Inicial>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_VARDECLARACION_ID_COLONEQ :
                //<Var Declaracion> ::= ID ':=' <Inicializar Var>
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_VARDECLARACION_COMMA_ID_COLONEQ :
                //<Var Declaracion> ::= <Var Declaracion> ',' ID ':=' <Inicializar Var>
                //todo: Create a new object using the stored user objects.
                return token.Tokens[2].UserObject.ToString();

                case (int)RuleConstants.RULE_INICIAL_ID :
                //<Inicial> ::= ID
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_INICIAL_ID_LBRACKET_RBRACKET :
                //<Inicial> ::= ID '[' <Expresion> ']'
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_INICIALIZARVAR :
                //<Inicializar Var> ::= <Expresion>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_TIPOBASE_ENTERO :
                //<Tipo Base> ::= entero
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_TIPOBASE_DECIMAL :
                //<Tipo Base> ::= decimal
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_TIPOBASE_CADENA :
                //<Tipo Base> ::= cadena
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_TIPOBASE_CARACTER :
                //<Tipo Base> ::= caracter
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_TIPOVALOR_DENTERO :
                //<Tipo Valor> ::= DENTERO
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_TIPOVALOR_DDECIMAL :
                //<Tipo Valor> ::= DDECIMAL
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_TIPOVALOR_DCADENA :
                //<Tipo Valor> ::= DCADENA
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_TIPOVALOR_DCARACTER :
                //<Tipo Valor> ::= DCARACTER
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_OPADD_PLUS :
                //<Op Add> ::= '+'
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_OPADD_MINUS :
                //<Op Add> ::= '-'
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_OPMULT_TIMES :
                //<Op Mult> ::= '*'
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_OPMULT_DIV :
                //<Op Mult> ::= '/'
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_OPRELACIONAL_LT :
                //<Op Relacional> ::= '<'
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_OPRELACIONAL_GT :
                //<Op Relacional> ::= '>'
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_OPRELACIONAL_EQGT :
                //<Op Relacional> ::= '=>'
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_OPRELACIONAL_LTEQ :
                //<Op Relacional> ::= '<='
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_OPRELACIONAL_EQ :
                //<Op Relacional> ::= '='
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_OPRELACIONAL_LTGT :
                //<Op Relacional> ::= '<>'
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_OPLOGICO_Y :
                //<Op Logico> ::= y
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_OPLOGICO_O :
                //<Op Logico> ::= o
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_EXPRESION :
                //<Expresion> ::= <Exp List>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_EXPLIST :
                //<Exp List> ::= <Logica Exp>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_LOGICAEXP :
                //<Logica Exp> ::= <Logica Exp> <Op Logico> <Compare Exp>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_LOGICAEXP2 :
                //<Logica Exp> ::= <Compare Exp>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_COMPAREEXP :
                //<Compare Exp> ::= <Compare Exp> <Op Relacional> <Add Exp>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_COMPAREEXP2 :
                //<Compare Exp> ::= <Add Exp>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_ADDEXP :
                //<Add Exp> ::= <Add Exp> <Op Add> <Mult Exp>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_ADDEXP2 :
                //<Add Exp> ::= <Mult Exp>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_MULTEXP :
                //<Mult Exp> ::= <Mult Exp> <Op Mult> <Unario>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_MULTEXP2 :
                //<Mult Exp> ::= <Unario>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_UNARIO_MINUS :
                //<Unario> ::= '-' <Unario>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_UNARIO :
                //<Unario> ::= <Primario>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_PRIMARIO :
                //<Primario> ::= <Tipo Valor>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_PRIMARIO_ID :
                //<Primario> ::= ID
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_PRIMARIO_LPAREN_RPAREN :
                //<Primario> ::= '(' <Expresion> ')'
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECSI_SI_ENTONCES_FINSI :
                //<Dec Si> ::= Si <Condicion> Entonces <Dec List> FinSi
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECSI_SI_ENTONCES_FINSI2 :
                //<Dec Si> ::= Si <Condicion> Entonces <Dec List> <Dec Si Contrario> FinSi
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_CONDICION_LPAREN_RPAREN :
                //<Condicion> ::= '(' <Expresion> ')'
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_CONDICION_LPAREN_RPAREN2 :
                //<Condicion> ::= <Condicion> <Op Relacional> '(' <Expresion> ')'
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_CONDICION_LPAREN_RPAREN3 :
                //<Condicion> ::= <Condicion> <Op Logico> '(' <Expresion> ')'
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECSICONTRARIO_DE_LO_CONTRARIO :
                //<Dec Si Contrario> ::= De lo contrario <Dec List>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECREPETIRMIENTRAS_REPETIR_MIENTRAS_FINREPETIR :
                //<Dec Repetir Mientras> ::= Repetir Mientras <Expresion> <Dec List> FinRepetir
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECREPETIRHACER_REPETIR_HACER_MIENTRAS_FINREPETIR :
                //<Dec Repetir Hacer> ::= Repetir Hacer <Dec List> Mientras <Expresion> FinRepetir
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_DECRPETIRPARA_REPETIR_PARA_DESDE_HASTA_FINREPETIR :
                //<Dec Rpetir Para> ::= Repetir Para <Hasta Dato> Desde <Hasta Dato> Hasta <Hasta Dato> <Dec List> FinRepetir
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_HASTADATO_ID :
                //<Hasta Dato> ::= ID
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_HASTADATO_DENTERO :
                //<Hasta Dato> ::= DENTERO
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_DECLLAMARFUNCION_ID_LPAREN_RPAREN :
                //<Dec Llamar Funcion> ::= ID '(' ')'
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_DECLLAMARFUNCION_ID_LPAREN_RPAREN2 :
                //<Dec Llamar Funcion> ::= ID '(' <ParametroLlamada> ')'
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_PARAMETROLLAMADA_ID :
                //<ParametroLlamada> ::= ID
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_PARAMETROLLAMADA :
                //<ParametroLlamada> ::= <Tipo Valor>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_PARAMETROLLAMADA_COMMA :
                //<ParametroLlamada> ::= <ParametroLlamada> ',' <Tipo Valor>
                //todo: Create a new object using the stored user objects.
                return null;

                case (int)RuleConstants.RULE_PARAMETROLLAMADA_COMMA_ID :
                //<ParametroLlamada> ::= <ParametroLlamada> ',' ID
                //todo: Create a new object using the stored user objects.
                return token.Tokens[2].UserObject.ToString();

                case (int)RuleConstants.RULE_DECFUNCIONPARAMETROS_ID_LPAREN_RPAREN :
                //<Dec Funcion Parametros> ::= ID '(' ')'
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_DECFUNCIONPARAMETROS_ID_LPAREN_RPAREN2 :
                //<Dec Funcion Parametros> ::= ID '(' <ParametroRecibe> ')'
                //todo: Create a new object using the stored user objects.
                return token.Tokens[0].UserObject.ToString();

                case (int)RuleConstants.RULE_PARAMETRORECIBE_ID :
                //<ParametroRecibe> ::= <Tipo Base> ID
                //todo: Create a new object using the stored user objects.
                return token.Tokens[1].UserObject.ToString();

                case (int)RuleConstants.RULE_PARAMETRORECIBE_COMMA_ID :
                //<ParametroRecibe> ::= <ParametroRecibe> ',' <Tipo Base> ID
                //todo: Create a new object using the stored user objects.
                return token.Tokens[3].UserObject.ToString();

            }
            throw new RuleException("Unknown rule");
        }

        private void AcceptEvent(LALRParser parser, AcceptEventArgs args)
        {
            //todo: Use your fully reduced args.Token.UserObject
            //MessageBox.Show("Analisis Completo");
        }

        private void TokenErrorEvent(LALRParser parser, TokenErrorEventArgs args)
        {
            //string message = "Token error with input: '"+args.Token.ToString()+"'";
            //todo: Report message to UI?
            int line = args.Token.Location.LineNr + 1;
            int col = args.Token.Location.ColumnNr + 1;
            String archivo, descripcion, linea, columna;
            archivo = Interfaz.nombre_archivo;
            descripcion = " Simbolo Error Token" + args.Token.ToString();
            linea = line.ToString(); ;
            columna = col.ToString();
            if (Listas.controlError > 20)
            {
                args.Continue = false;
            }
            else
            {
                if (Listas.controlLinea != line)
                {
                    Errores er = new Errores(Listas.controlNum.ToString(), archivo, descripcion, linea, columna);
                    Listas.list_Error.AddLast(er);
                    Listas.controlLinea = line;
                }
                Listas.controlError++;
                args.Continue = true;
            }
        }

        private void ParseErrorEvent(LALRParser parser, ParseErrorEventArgs args)
        {
            //string message = "Parse error caused by token: '"+args.UnexpectedToken.ToString()+"'";
            //todo: Report message to UI?
            int line = args.UnexpectedToken.Location.LineNr + 1;
            int col = args.UnexpectedToken.Location.ColumnNr + 1;
            String archivo, descripcion, linea, columna;
            archivo = Interfaz.nombre_archivo;
            descripcion = "Simbolo Error: " + args.UnexpectedToken.ToString();
            linea = line.ToString(); ;
            columna = col.ToString();
            if (Listas.controlError > 20)
            {

                args.Continue = ContinueMode.Stop;

            }
            else
            {
                if (Listas.controlLinea != line)
                {
                    Listas.controlNum++;
                    Errores er = new Errores(Listas.controlNum.ToString(), archivo, descripcion, linea, columna);
                    Listas.list_Error.AddLast(er);
                    Listas.controlLinea = line;
                    Listas.posiciones.Add(args.UnexpectedToken.Location.Position);
                }
                Listas.controlError++;
                args.Continue = ContinueMode.Skip;
            }
        }


    }
}*/
